==> pnetC-0.6.0.tar.gz: pnetC-0.6.0/libc/time/gmtime.c <==
/*
 * gmtime.c - Convert a time_t value into GMT or local time.
 *
 * This file is part of the Portable.NET C library.
 * Copyright (C) 2002  Southern Storm Software, Pty Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <time.h>
#include "time-defs.h"

static struct tm gmbuf;
static struct tm locbuf;

struct tm *
gmtime (time_t *timer)
{
  __syscall_unpack_time (TIME_TO_TICKS (*timer), (__native__ int)&gmbuf,
                         (_Bool)0);
  return &gmbuf;
}

struct tm *
gmtime_r (time_t * __restrict timer, struct tm * __restrict tp)
{
  __syscall_unpack_time (TIME_TO_TICKS (*timer), (__native__ int)tp,
                         (_Bool)0);
  return tp;
}

struct tm *
localtime (time_t *timer)
{
  if (!__tz_is_set)
    tzset ();
  __syscall_unpack_time (TIME_TO_TICKS (*timer), (__native__ int)&locbuf,
                         (_Bool)1);
  return &locbuf;
}

struct tm *
localtime_r (time_t * __restrict timer, struct tm * __restrict tp)
{
  if (!__tz_is_set)
    tzset ();
  __syscall_unpack_time (TIME_TO_TICKS (*timer), (__native__ int)tp,
                         (_Bool)1);
  return tp;
}

==> pnetC-0.7.4.tar.gz: pnetC-0.7.4/libc/time/gmtime.c <==
/*
 * gmtime.c - Convert a time_t value into GMT or local time.
 *
 * This file is part of the Portable.NET C library.
 * Copyright (C) 2002  Southern Storm Software, Pty Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <time.h>
#include "time-defs.h"

static struct tm __declspec(thread) gmbuf;
static struct tm __declspec(thread) locbuf;

struct tm *
gmtime (time_t *timer)
{
  __syscall_unpack_time (TIME_TO_TICKS (*timer), (long)&gmbuf,
                         (_Bool)0);
  return &gmbuf;
}

struct tm *
gmtime_r (time_t * __restrict timer, struct tm * __restrict tp)
{
  __syscall_unpack_time (TIME_TO_TICKS (*timer), (long)tp,
                         (_Bool)0);
  return tp;
}

struct tm *
localtime (time_t *timer)
{
  if (!__tz_is_set)
    tzset ();
  __syscall_unpack_time (TIME_TO_TICKS (*timer), (long)&locbuf,
                         (_Bool)1);
  return &locbuf;
}

struct tm *
localtime_r (time_t * __restrict timer, struct tm * __restrict tp)
{
  if (!__tz_is_set)
    tzset ();
  __syscall_unpack_time (TIME_TO_TICKS (*timer), (long)tp,
                         (_Bool)1);
  return tp;
}
